Module: Georss4rb::Location
- Defined in:
- lib/georss4rb.rb
Instance Method Summary collapse
- #georss_tags ⇒ Object
-
#located? ⇒ Boolean
True if the feed or the item has some location info.
-
#location ⇒ Object
Returns a Georss4rb::Geometry object if info about the location is found.
Instance Method Details
#georss_tags ⇒ Object
16 17 18 19 20 21 |
# File 'lib/georss4rb.rb', line 16 def if !located? get_location_info end end |
#located? ⇒ Boolean
True if the feed or the item has some location info
24 25 26 |
# File 'lib/georss4rb.rb', line 24 def located? !@location.nil? end |
#location ⇒ Object
Returns a Georss4rb::Geometry object if info about the location is found.
Returns nil if no location info is found.
9 10 11 12 13 14 |
# File 'lib/georss4rb.rb', line 9 def location if !located? get_location_info end @location end |